@@ -5,6 +5,12 @@
   (defined(x ## _FIRST) && (x ## _FIRST <= LIBCURL_VERSION_NUM) && \
    (!defined(x ## _LAST) || ( x ## _LAST >= LIBCURL_VERSION_NUM)))
 
+#define CURLALTSVC_ALTUSED_FIRST 0x074001 /* Added in 7.64.1 */
+#define CURLALTSVC_H1_FIRST 0x074001 /* Added in 7.64.1 */
+#define CURLALTSVC_H2_FIRST 0x074001 /* Added in 7.64.1 */
+#define CURLALTSVC_H3_FIRST 0x074001 /* Added in 7.64.1 */
+#define CURLALTSVC_IMMEDIATELY_FIRST 0x074001 /* Added in 7.64.1 */
+#define CURLALTSVC_READONLYFILE_FIRST 0x074001 /* Added in 7.64.1 */
 #define CURLAUTH_ANY_FIRST 0x070a06 /* Added in 7.10.6 */
 #define CURLAUTH_ANYSAFE_FIRST 0x070a06 /* Added in 7.10.6 */
 #define CURLAUTH_BASIC_FIRST 0x070a06 /* Added in 7.10.6 */
@@ -338,6 +344,8 @@
 #define CURLOPT_ACCEPTTIMEOUT_MS_FIRST 0x071800 /* Added in 7.24.0 */
 #define CURLOPT_ACCEPT_ENCODING_FIRST 0x071506 /* Added in 7.21.6 */
 #define CURLOPT_ADDRESS_SCOPE_FIRST 0x071300 /* Added in 7.19.0 */
+#define CURLOPT_ALTSVC_FIRST 0x074001 /* Added in 7.64.1 */
+#define CURLOPT_ALTSVC_CTRL_FIRST 0x074001 /* Added in 7.64.1 */
 #define CURLOPT_APPEND_FIRST 0x071100 /* Added in 7.17.0 */
 #define CURLOPT_AUTOREFERER_FIRST 0x070100 /* Added in 7.1 */
 #define CURLOPT_BUFFERSIZE_FIRST 0x070a00 /* Added in 7.10 */
@@ -430,8 +438,6 @@
 #define CURLOPT_HTTP_CONTENT_DECODING_FIRST 0x071002 /* Added in 7.16.2 */
 #define CURLOPT_HTTP_TRANSFER_DECODING_FIRST 0x071002 /* Added in 7.16.2 */
 #define CURLOPT_HTTP_VERSION_FIRST 0x070901 /* Added in 7.9.1 */
-#define CURLOPT_TRAILERFUNCTION_FIRST 0x074000 /* Added in 7.64.0 */
-#define CURLOPT_TRAILERDATA_FIRST 0x074000 /* Added in 7.64.0 */
 #define CURLOPT_IGNORE_CONTENT_LENGTH_FIRST 0x070e01 /* Added in 7.14.1 */
 #define CURLOPT_INFILE_FIRST 0x070100 /* Added in 7.1 */
 #define CURLOPT_INFILESIZE_FIRST 0x070100 /* Added in 7.1 */
@@ -626,6 +632,8 @@
 #define CURLOPT_TLSAUTH_PASSWORD_FIRST 0x071504 /* Added in 7.21.4 */
 #define CURLOPT_TLSAUTH_TYPE_FIRST 0x071504 /* Added in 7.21.4 */
 #define CURLOPT_TLSAUTH_USERNAME_FIRST 0x071504 /* Added in 7.21.4 */
+#define CURLOPT_TRAILERDATA_FIRST 0x074000 /* Added in 7.64.0 */
+#define CURLOPT_TRAILERFUNCTION_FIRST 0x074000 /* Added in 7.64.0 */
 #define CURLOPT_TRANSFERTEXT_FIRST 0x070101 /* Added in 7.1.1 */
 #define CURLOPT_TRANSFER_ENCODING_FIRST 0x071506 /* Added in 7.21.6 */
 #define CURLOPT_UNIX_SOCKET_PATH_FIRST 0x072800 /* Added in 7.40.0 */
@@ -731,6 +739,7 @@
 #define CURLSSLBACKEND_QSOSSL_FIRST 0x072200 /* Added in 7.34.0 */
 #define CURLSSLBACKEND_QSOSSL_LAST 0x072601 /* Last featured in 7.38.1 */
 #define CURLSSLBACKEND_SCHANNEL_FIRST 0x072200 /* Added in 7.34.0 */
+#define CURLSSLBACKEND_SECURETRANSPORT_FIRST 0x074001 /* Added in 7.64.1 */
 #define CURLSSLBACKEND_WOLFSSL_FIRST 0x073100 /* Added in 7.49.0 */
 #define CURLSSLOPT_ALLOW_BEAST_FIRST 0x071900 /* Added in 7.25.0 */
 #define CURLSSLOPT_NO_REVOKE_FIRST 0x072c00 /* Added in 7.44.0 */
@@ -875,8 +884,6 @@
 #define CURL_PUSH_OK_FIRST 0x072c00 /* Added in 7.44.0 */
 #define CURL_READFUNC_ABORT_FIRST 0x070c01 /* Added in 7.12.1 */
 #define CURL_READFUNC_PAUSE_FIRST 0x071200 /* Added in 7.18.0 */
-#define CURL_TRAILERFUNC_OK_FIRST 0x074000 /* Added in 7.64.0 */
-#define CURL_TRAILERFUNC_ABORT_FIRST 0x074000 /* Added in 7.64.0 */
 #define CURL_REDIR_GET_ALL_FIRST 0x071301 /* Added in 7.19.1 */
 #define CURL_REDIR_POST_301_FIRST 0x071301 /* Added in 7.19.1 */
 #define CURL_REDIR_POST_302_FIRST 0x071301 /* Added in 7.19.1 */
@@ -923,7 +930,10 @@
 #define CURL_TIMECOND_NONE_FIRST 0x070907 /* Added in 7.9.7 */
 #define CURL_TLSAUTH_NONE_FIRST 0x071504 /* Added in 7.21.4 */
 #define CURL_TLSAUTH_SRP_FIRST 0x071504 /* Added in 7.21.4 */
+#define CURL_TRAILERFUNC_ABORT_FIRST 0x074000 /* Added in 7.64.0 */
+#define CURL_TRAILERFUNC_OK_FIRST 0x074000 /* Added in 7.64.0 */
 #define CURL_UPKEEP_INTERVAL_DEFAULT_FIRST 0x073e00 /* Added in 7.62.0 */
+#define CURL_VERSION_ALTSVC_FIRST 0x074001 /* Added in 7.64.1 */
 #define CURL_VERSION_ASYNCHDNS_FIRST 0x070a07 /* Added in 7.10.7 */
 #define CURL_VERSION_BROTLI_FIRST 0x073900 /* Added in 7.57.0 */
 #define CURL_VERSION_CONV_FIRST 0x070f04 /* Added in 7.15.4 */
